@@ -12,11 +12,11 @@
 
 // #include the widget headers so that we can call the get_type() static methods:
 
-#include "./client.h"
-#include "./entry.h"
-#include "./schema.h"
-#include "./value.h"
-#include "./changeset.h"
+#include "client.h"
+#include "entry.h"
+#include "schema.h"
+#include "value.h"
+#include "changeset.h"
 
 extern "C"
 {
